@@ -1,11 +1,11 @@
-use toucan_ecs::Registry;
+use toucan_ecs::World;
 
 use crate::components::{Mass, Position, Velocity};
 
-pub fn prepare_for_view() -> Registry {
-    let mut registry = Registry::new();
+pub fn prepare_for_view() -> World {
+    let mut world = World::new();
 
-    for i in 0..=10 {
+    for i in 1..=10 {
         let f = i as f32;
         let position = Position { x: f, y: -f };
         let velocity = Velocity {
@@ -13,16 +13,16 @@ pub fn prepare_for_view() -> Registry {
             dy: -f / 10.0,
         };
         let mass = Mass(f);
-        let _entity = registry.create_with((position, velocity, mass));
+        let _entity = world.create_with((position, velocity, mass));
     }
 
-    registry
+    world
 }
 
-pub fn prepare_for_optional_view() -> Registry {
-    let mut registry = Registry::new();
+pub fn prepare_for_complex_view() -> World {
+    let mut world = World::new();
 
-    for i in 0..=10 {
+    for i in 1..=10 {
         let f = i as f32;
         let position = Position { x: f, y: -f };
         let velocity = Velocity {
@@ -30,14 +30,14 @@ pub fn prepare_for_optional_view() -> Registry {
             dy: -f / 10.0,
         };
         let mass = Mass(f);
-        let entity = registry.create();
-        registry.attach_one(entity, position);
+        let entity = world.create();
+        world.attach_one(entity, position);
         if i % 2 == 0 {
-            registry.attach_one(entity, velocity);
+            world.attach_one(entity, velocity);
         } else {
-            registry.attach_one(entity, mass);
+            world.attach_one(entity, mass);
         }
     }
 
-    registry
+    world
 }
